/*
** Module   : LogCursorPos.java
** Abstract : directive to query the cursor position (row/col) and record it in
**            the results
**
** Copyright (c) 2009-2021, Golden Code Development Corporation.
**
** -#- -I- --Date-- ---------------------------------------Description----------------------------------------
** 001 GES 20090126 Directive to query the cursor position (row/col) and record it in the results.
** 002 CA  20210827 Refactored to allow other test types, beside terminal (which can be executed from the same 
**                  test suite).  Added SOAP and REST web service tests.
*/

/*
** This program is free software: you can redistribute it and/or modify
** it under the terms of the GNU Affero General Public License as
** published by the Free Software Foundation, either version 3 of the
** License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU Affero General Public License for more details.
**
** You should have received a copy of the GNU Affero General Public License
** along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package com.goldencode.harness.test;

import com.goldencode.harness.*;
import com.goldencode.harness.terminal.*;

/**
 * Directive to query the cursor position (row/col) and record it in the
 * results.
 */
public class LogCursorPos
extends Report
implements TerminalTestable
{
   /** Short name for the activity. */
   private static final String NAME = "LOG-CURSOR-POS";
   
   /** Format specification for creating a description of this step. */
   private static final String SPEC = "row = '%d'; column = '%d';";
   
   /**
    * Default constructor.
    */
   public LogCursorPos()
   {
      super(NAME, "");
   }
   
   /**
    * Execute the directive of the test using the given terminal as the data
    * sink and/or source for the operation.
    *
    * @param    term
    *           The terminal that represents the system under test.
    */
   @Override
   public void execute(Terminal term)
   {
      int row = term.getCursorRow();
      int col = term.getCursorColumn();
      setDescription(String.format(SPEC, row, col));
      setStatus(Status.PASSED, "");
   }
}
